@@ -29,7 +29,6 @@
 #include "ephy-file-helpers.h"
 #include "ephy-flatpak-utils.h"
 #include "ephy-location-entry.h"
-#include "ephy-notebook.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-title-box.h"
@@ -60,7 +59,7 @@ struct _EphyHeaderBar {
   EphyActionBarStart *action_bar_start;
   EphyActionBarEnd *action_bar_end;
   GtkWidget *page_menu_button;
-  GtkWidget *zoom_level_button;
+  GtkWidget *zoom_level_label;
   GtkWidget *restore_button;
   GtkWidget *combined_stop_reload_button;
   GtkWidget *combined_stop_reload_image;
@@ -265,7 +264,7 @@ ephy_header_bar_constructed (GObject *object)
   g_type_ensure (G_TYPE_THEMED_ICON);
   builder = gtk_builder_new_from_resource ("/org/gnome/epiphany/gtk/page-menu-popover.ui");
   page_menu_popover = GTK_WIDGET (gtk_builder_get_object (builder, "page-menu-popover"));
-  header_bar->zoom_level_button = GTK_WIDGET (gtk_builder_get_object (builder, "zoom-level"));
+  header_bar->zoom_level_label = GTK_WIDGET (gtk_builder_get_object (builder, "zoom-level"));
   if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_APPLICATION) {
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-separator")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-button")));
@@ -278,7 +277,6 @@ ephy_header_bar_constructed (GObject *object)
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "override-text-encoding-button")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "keyboard-shortcuts-button")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "help-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "passwords-separator")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "import-export-separator")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "import-export-menu")));
   } else if (ephy_is_running_inside_flatpak ()) {
@@ -306,6 +304,7 @@ ephy_header_bar_constructed (GObject *object)
                           gtk_image_new_from_icon_name ("open-menu",
                                                         GTK_ICON_SIZE_LARGE_TOOLBAR));
   }
+  g_settings_bind (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_WEBEXTENSIONS, gtk_builder_get_object (builder, "extensions-button"), "visible", G_SETTINGS_BIND_DEFAULT);
 
   gtk_menu_button_set_popover (GTK_MENU_BUTTON (button), page_menu_popover);
   g_object_unref (builder);
@@ -337,7 +336,7 @@ ephy_header_bar_constructed (GObject *object)
   if (ephy_profile_dir_is_web_application ()) {
     GtkWidget *navigation_box = ephy_action_bar_start_get_navigation_box (header_bar->action_bar_start);
 
-    g_settings_bind (EPHY_SETTINGS_WEB_APP, EPHY_PREFS_WEB_APP_MOBILE_CAPABLE, navigation_box, "visible", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_INVERT_BOOLEAN);
+    g_settings_bind (EPHY_SETTINGS_WEB_APP, EPHY_PREFS_WEB_APP_SHOW_NAVIGATION_BUTTONS, navigation_box, "visible", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_INVERT_BOOLEAN);
   }
 }
 
@@ -384,12 +383,6 @@ ephy_header_bar_get_title_widget (EphyHeaderBar *header_bar)
   return header_bar->title_widget;
 }
 
-GtkWidget *
-ephy_header_bar_get_zoom_level_button (EphyHeaderBar *header_bar)
-{
-  return header_bar->zoom_level_button;
-}
-
 GtkWidget *
 ephy_header_bar_get_page_menu_button (EphyHeaderBar *header_bar)
 {
@@ -456,3 +449,19 @@ ephy_header_bar_start_change_combined_stop_reload_state (EphyHeaderBar *header_b
                                  _(REFRESH_BUTTON_TOOLTIP));
   }
 }
+
+void
+ephy_header_bar_set_zoom_level (EphyHeaderBar *header_bar,
+                                gdouble        zoom)
+{
+  g_autofree gchar *zoom_level = g_strdup_printf ("%2.0f%%", zoom * 100);
+
+  gtk_label_set_label (GTK_LABEL (header_bar->zoom_level_label), zoom_level);
+}
+
+void
+ephy_header_bar_add_browser_action (EphyHeaderBar *header_bar,
+                                    GtkWidget     *action)
+{
+  ephy_action_bar_end_add_browser_action (header_bar->action_bar_end, action);
+}
